.. currentmodule:: pyfits

******************************
Exceptions and Utility Classes
******************************

Exceptions
==========

:class:`VerifyError`
--------------------

.. autoclass:: VerifyError
   :members:
   :undoc-members:
   :show-inheritance:

Utility Classes
===============

:class:`Delayed`
----------------

.. autoclass:: Delayed
   :members:
   :undoc-members:
   :show-inheritance:

:class:`Undefined`
------------------

.. autoclass:: Undefined
   :members:
   :undoc-members:
   :show-inheritance:
